package com.migao.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.migao.config.response.BasePageRequest;
import com.migao.config.response.PageBeanOne;
import com.migao.config.response.ResponseBean;
import com.migao.entity.po.DocumentSharing;
import com.migao.entity.po.ProjectStage;
import com.migao.entity.po.ProjectType;
import com.migao.entity.vo.req.DocumentSharingInsertReq;
import com.migao.entity.vo.req.DocumentSharingQueryReq;
import com.migao.entity.vo.req.DocumentSharingUpdateReq;
import com.migao.entity.vo.res.DictionaryListRes;
import com.migao.entity.vo.res.DocumentSharingPageQueryRes;
import com.migao.entity.vo.res.DocumentSharingQueryRes;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * @author dingsong
 */
public interface DocumentSharingService extends IService<DocumentSharing> {
    /**
     * 新增
     * @param doc
     * @return
     */
    ResponseBean<?> insert(DocumentSharingInsertReq doc);


    /**
     * 删除
     * @param id 文档共享id
     * @return
     */
    ResponseBean<?> deleteById(String id);

    /**
     * 更新
     * @param documentSharingUpdateReq 文档共享更新请求
     * @return
     */
    ResponseBean<?> update(DocumentSharingUpdateReq documentSharingUpdateReq);

    /**
     * 通过id查询单条数据
     * @param id 文档共享id
     * @return
     */
    ResponseBean<DocumentSharingQueryRes> findById(String id);

    /**
     * 分页查询所有文档共享数据
     * @param basePageRequest 页数
     * @return
     */
    ResponseBean<PageBeanOne<DocumentSharingPageQueryRes>> pageQueryAll(BasePageRequest basePageRequest);

    /**
     * 分页查询当前用户文档共享数据
     * @param basePageRequest 页数
     * @return
     */
    ResponseBean<PageBeanOne<DocumentSharingPageQueryRes>> pageQueryById(BasePageRequest basePageRequest);


    /**
     * 分页模糊查询所有文档共享数据
     * @param documentSharingQuery 关键字
     * @return
     */
    ResponseBean<PageBeanOne<DocumentSharingPageQueryRes>> pageQueryOne(DocumentSharingQueryReq documentSharingQuery);

    /**
     * 分页模糊查询当前用户文档共享数据
     * @param documentSharingQuery 关键字
     * @return
     */
    ResponseBean<PageBeanOne<DocumentSharingPageQueryRes>> pageQueryOneById(DocumentSharingQueryReq documentSharingQuery);

    /**
     * 下载单个文件
     * @param response 响应
     * @param id 文档共享id
     * @return
     */
    ResponseBean<?> download(HttpServletResponse response, String id);

    /**
     * 文档格式分类下拉列表
     * @return
     */
    public ResponseBean<List<DictionaryListRes>> documentFormatClassify();

    /**
     * 项目类别下拉列表
     * @return
     */
    public ResponseBean<List<ProjectType>> findProjectType();

    /**
     * 项目阶段下拉列表
     * @return
     */
    public ResponseBean<List<ProjectStage>> findProjectStage();
}
